@@ -4,13 +4,13 @@ from __future__ import division, absolute_import, unicode_literals
 import re
 from io import StringIO
 
-from cola import core
-from cola import gitcfg
-from cola import utils
-from cola import version
-from cola.git import git
-from cola.git import STDOUT
-from cola.i18n import N_
+from . import core
+from . import gitcfg
+from . import utils
+from . import version
+from .git import git
+from .git import STDOUT
+from .i18n import N_
 
 
 EMPTY_TREE_SHA1 = '4b825dc642cb6eb9a060e54bf8d69288fbee4904'
@@ -76,7 +76,7 @@ def all_files(*args):
     return sorted([f for f in ls_files.split('\0') if f])
 
 
-class _current_branch:
+class _current_branch(object):
     """Cache for current_branch()"""
     key = None
     value = None
@@ -150,16 +150,20 @@ def for_each_ref_basename(refs, git=git):
     """Return refs starting with 'refs'."""
     out = git.for_each_ref(refs, format='%(refname)')[STDOUT]
     output = out.splitlines()
-    non_heads = filter(lambda x: not x.endswith('/HEAD'), output)
+    non_heads = [x for x in output if not x.endswith('/HEAD')]
     return list(map(lambda x: x[len(refs) + 1:], non_heads))
 
 
+def _triple(x, y):
+    return (x, len(x) + 1, y)
+
+
 def all_refs(split=False, git=git):
     """Return a tuple of (local branches, remote branches, tags)."""
     local_branches = []
     remote_branches = []
     tags = []
-    triple = lambda x, y: (x, len(x) + 1, y)
+    triple = _triple
     query = (triple('refs/tags', tags),
              triple('refs/heads', local_branches),
              triple('refs/remotes', remote_branches))
@@ -223,6 +227,8 @@ def commit_diff(sha1, git=git):
 
 
 _diff_overrides = {}
+
+
 def update_diff_overrides(space_at_eol, space_change,
                           all_space, function_context):
     _diff_overrides['ignore_space_at_eol'] = space_at_eol
@@ -388,7 +394,7 @@ def format_patchsets(to_export, revs, output='patches'):
             master_idx = revs[cur_master_idx:].index(rev)
             master_idx += cur_master_idx
         except ValueError:
-            master_idx  = revs.index(rev)
+            master_idx = revs.index(rev)
 
         if master_idx == cur_master_idx + 1:
             patches_to_export[patchset_idx].append(rev)
@@ -579,13 +585,14 @@ def parse_ls_tree(rev):
             objtype = match.group(2)
             sha1 = match.group(3)
             filename = match.group(4)
-            output.append((mode, objtype, sha1, filename,) )
+            output.append((mode, objtype, sha1, filename,))
     return output
 
 
 # A regex for matching the output of git(log|rev-list) --pretty=oneline
 REV_LIST_REGEX = re.compile(r'^([0-9a-f]{40}) (.*)$')
 
+
 def parse_rev_list(raw_revs):
     """Parse `git log --pretty=online` output into (SHA-1, summary) pairs."""
     revs = []
