@@ -1,25 +1,21 @@
 from __future__ import division, absolute_import, unicode_literals
-
 import os
 import re
 
-from PyQt4 import QtGui
-
-from cola import cmds
-from cola import core
-from cola import difftool
-from cola import gitcmds
-from cola import icons
-from cola import qtutils
-from cola import utils
-from cola import git
-from cola.i18n import N_
-from cola.interaction import Interaction
-from cola.models import main
-from cola.widgets import completion
-from cola.widgets.browse import BrowseDialog
-from cola.widgets.selectcommits import select_commits
-from cola.compat import ustr
+from . import cmds
+from . import core
+from . import difftool
+from . import gitcmds
+from . import icons
+from . import qtutils
+from . import utils
+from . import git
+from .i18n import N_
+from .interaction import Interaction
+from .models import main
+from .widgets import completion
+from .widgets.browse import BrowseDialog
+from .widgets.selectcommits import select_commits
 
 
 def delete_branch():
@@ -84,21 +80,11 @@ def new_repo():
     :returns str: repository path or None if no repository was created.
 
     """
-    dlg = QtGui.QFileDialog()
-    dlg.setFileMode(QtGui.QFileDialog.Directory)
-    dlg.setOption(QtGui.QFileDialog.ShowDirsOnly)
-    dlg.show()
-    dlg.raise_()
-    if dlg.exec_() != QtGui.QFileDialog.Accepted:
-        return None
-    paths = dlg.selectedFiles()
-    if not paths:
-        return None
-    path = ustr(paths[0])
+    path = qtutils.opendir_dialog(N_('New Repository...'), core.getcwd())
     if not path:
         return None
     # Avoid needlessly calling `git init`.
-    if git.is_git_dir(path):
+    if git.is_git_worktree(path) or git.is_git_dir(path):
         # We could prompt here and confirm that they really didn't
         # mean to open an existing repository, but I think
         # treating it like an "Open" is a sensible DWIM answer.
@@ -297,12 +283,25 @@ def report_clone_repo_errors(task):
                          message=task.cmd.error_message,
                          details=task.cmd.error_details)
 
+
 def rename_branch():
     """Launch the 'Rename Branch' dialogs."""
     branch = choose_branch(N_('Rename Existing Branch'), N_('Select'))
     if not branch:
         return
-    new_branch = choose_branch(N_('Enter Branch New Name'), N_('Rename'))
+    new_branch = choose_branch(N_('Enter New Branch Name'), N_('Rename'))
     if not new_branch:
         return
     cmds.do(cmds.RenameBranch, branch, new_branch)
+
+
+def reset_branch_head():
+    ref = choose_ref(N_('Reset Branch Head'), N_('Reset'), default='HEAD^')
+    if ref:
+        cmds.do(cmds.ResetBranchHead, ref)
+
+
+def reset_worktree():
+    ref = choose_ref(N_('Reset Worktree'), N_('Reset'))
+    if ref:
+        cmds.do(cmds.ResetWorktree, ref)
