@@ -9,20 +9,19 @@ if __name__ == '__main__':
     srcdir = os.path.dirname(os.path.dirname(__file__))
     sys.path.insert(1, srcdir)
 
-from cola.git import git
-from cola.git import STDOUT
-from cola.decorators import memoize
-from cola._version import VERSION
+from .git import git
+from .git import STDOUT
+from .decorators import memoize
+from ._version import VERSION
 
 # minimum version requirements
 _versions = {
-    # git-diff learned --patience in 1.6.2
-    # git-mergetool learned --no-prompt in 1.6.2
-    # git-difftool moved out of contrib in git 1.6.3
+    # git diff learned --patience in 1.6.2
+    # git mergetool learned --no-prompt in 1.6.2
+    # git difftool moved out of contrib in git 1.6.3
     'git': '1.6.3',
     'python': '2.6',
-    'pyqt': '4.4',
-    'pyqt_qrunnable': '4.4',
+    # git diff --submodule was introduced in 1.6.6
     'diff-submodule': '1.6.6',
 }
 
@@ -70,6 +69,7 @@ def git_version_str():
     """Returns the current GIT version"""
     return git.version()[STDOUT].strip()
 
+
 @memoize
 def git_version():
     """Returns the current GIT version"""
@@ -83,10 +83,11 @@ def git_version():
 
 def print_version(brief=False):
     if brief:
-        print('%s' % version())
+        msg = '%s\n' % version()
     else:
-        print('cola version %s' % version())
+        msg = 'cola version %s\n' % version()
+    sys.stdout.write(msg)
 
 
 if __name__ == '__main__':
-    print(version())
+    print_version(brief=True)
