@@ -1,38 +1,41 @@
 from __future__ import division, absolute_import, unicode_literals
-
 import re
 
-from PyQt4 import QtCore
-from PyQt4 import QtGui
-from PyQt4.QtCore import Qt
-from PyQt4.QtCore import SIGNAL
+from qtpy import QtCore
+from qtpy import QtGui
+from qtpy import QtWidgets
+from qtpy.QtCore import Qt
+from qtpy.QtCore import Signal
 
-from cola import core
-from cola import gitcmds
-from cola import icons
-from cola import qtutils
-from cola import utils
-from cola.models import main
-from cola.widgets import defs
-from cola.widgets import text
-from cola.compat import ustr
-
-
-UPDATE_SIGNAL = 'update()'
+from .. import core
+from .. import gitcmds
+from .. import icons
+from .. import qtutils
+from .. import utils
+from ..models import main
+from . import defs
+from . import text
 
 
 class CompletionLineEdit(text.HintedLineEdit):
     """An lineedit with advanced completion abilities"""
 
+    activated = Signal()
+    changed = Signal()
+    cleared = Signal()
+    enter = Signal()
+    up = Signal()
+    down = Signal()
+
     # Activation keys will cause a selected completion item to be chosen
     ACTIVATION_KEYS = (Qt.Key_Return, Qt.Key_Enter)
 
     # Navigation keys trigger signals that widgets can use for customization
     NAVIGATION_KEYS = {
-            Qt.Key_Return: 'return()',
-            Qt.Key_Enter: 'enter()',
-            Qt.Key_Up: 'up()',
-            Qt.Key_Down: 'down()',
+            Qt.Key_Return: 'enter',
+            Qt.Key_Enter: 'enter',
+            Qt.Key_Up: 'up',
+            Qt.Key_Down: 'down',
     }
 
     def __init__(self, model_factory, hint='', parent=None):
@@ -53,15 +56,11 @@ class CompletionLineEdit(text.HintedLineEdit):
         self._delegate = HighlightDelegate(self)
         completer.popup().setItemDelegate(self._delegate)
 
-        self.connect(self, SIGNAL('textChanged(QString)'), self._text_changed)
-
-        self.connect(self._completer, SIGNAL('activated(QString)'),
-                     self.choose_completion)
-
-        self.connect(self._completion_model, SIGNAL('updated()'),
-                     self._completions_updated, Qt.QueuedConnection)
-
-        self.connect(self, SIGNAL('destroyed(QObject*)'), self.dispose)
+        self.textChanged.connect(self._text_changed)
+        self._completer.activated.connect(self.choose_completion)
+        self._completion_model.updated.connect(self._completions_updated,
+                                               type=Qt.QueuedConnection)
+        self.destroyed.connect(self.dispose)
 
     def __del__(self):
         self.dispose()
@@ -92,9 +91,8 @@ class CompletionLineEdit(text.HintedLineEdit):
     def _is_case_sensitive(self, text):
         return bool([char for char in text if char.isupper()])
 
-    def _text_changed(self, text):
+    def _text_changed(self, full_text):
         match_text = self._last_word()
-        full_text = ustr(text)
         self._do_text_changed(full_text, match_text)
         self.complete_last_word()
 
@@ -118,7 +116,6 @@ class CompletionLineEdit(text.HintedLineEdit):
         This is the event handler for the QCompleter.activated(QString) signal,
         it is called when the user selects an item in the completer popup.
         """
-        completion = ustr(completion)
         if not completion:
             self._do_text_changed('', '')
             return
@@ -129,7 +126,7 @@ class CompletionLineEdit(text.HintedLineEdit):
         words.append(completion)
         text = core.list2cmdline(words)
         self.setText(text)
-        self.emit(SIGNAL('changed()'))
+        self.changed.emit()
         self._do_text_changed(text, '')
         self.popup().hide()
 
@@ -175,8 +172,8 @@ class CompletionLineEdit(text.HintedLineEdit):
             return
         # Select the first item
         idx = self._completion_model.index(0, 0)
-        selection = QtGui.QItemSelection(idx, idx)
-        mode = QtGui.QItemSelectionModel.Select
+        selection = QtCore.QItemSelection(idx, idx)
+        mode = QtCore.QItemSelectionModel.Select
         popup.selectionModel().select(selection, mode)
 
     def selected_completion(self):
@@ -191,7 +188,7 @@ class CompletionLineEdit(text.HintedLineEdit):
         item = self._completion_model.itemFromIndex(idx)
         if not item:
             return
-        return ustr(item.text())
+        return item.text()
 
     # Qt events
     def keyPressEvent(self, event):
@@ -215,7 +212,7 @@ class CompletionLineEdit(text.HintedLineEdit):
         # Clearing a line should always emit a signal
         is_empty = not bool(self.value())
         if is_empty:
-            self.emit(SIGNAL('cleared()'))
+            self.cleared.emit()
         return result
 
     def keyReleaseEvent(self, event):
@@ -225,9 +222,10 @@ class CompletionLineEdit(text.HintedLineEdit):
         if not visible:
             # If it's a navigation key then emit a signal
             try:
-                msg = self.NAVIGATION_KEYS[key]
                 event.accept()
-                self.emit(SIGNAL(msg))
+                msg = self.NAVIGATION_KEYS[key]
+                signal = getattr(self, msg)
+                signal.emit()
                 return
             except KeyError:
                 pass
@@ -238,13 +236,15 @@ class CompletionLineEdit(text.HintedLineEdit):
         selection = self.completion_selection()
         if visible and selection and key in self.ACTIVATION_KEYS:
             self.choose_completion(selection)
-            self.emit(SIGNAL('activated()'))
+            self.activated.emit()
             return
         return result
 
 
 class GatherCompletionsThread(QtCore.QThread):
 
+    items_gathered = Signal(object)
+
     def __init__(self, model):
         QtCore.QThread.__init__(self)
         self.model = model
@@ -260,33 +260,34 @@ class GatherCompletionsThread(QtCore.QThread):
             items = self.model.gather_matches(self.case_sensitive)
 
         if text is not None:
-            self.emit(SIGNAL('items_gathered(PyQt_PyObject)'), items)
+            self.items_gathered.emit(items)
 
 
-class HighlightDelegate(QtGui.QStyledItemDelegate):
+class HighlightDelegate(QtWidgets.QStyledItemDelegate):
     """A delegate used for auto-completion to give formatted completion"""
-    def __init__(self, parent=None): # model, parent=None):
-        QtGui.QStyledItemDelegate.__init__(self, parent)
+
+    def __init__(self, parent=None):
+        QtWidgets.QStyledItemDelegate.__init__(self, parent)
         self.highlight_text = ''
         self.case_sensitive = False
 
         self.doc = QtGui.QTextDocument()
         try:
             self.doc.setDocumentMargin(0)
-        except: # older PyQt4
+        except:  # older PyQt4
             pass
 
     def set_highlight_text(self, text, case_sensitive):
-        """Sets the text that will be made bold in the term name when displayed"""
+        """Sets the text that will be made bold when displayed"""
         self.highlight_text = text
         self.case_sensitive = case_sensitive
 
     def paint(self, painter, option, index):
         """Overloaded Qt method for custom painting of a model index"""
         if not self.highlight_text:
-            return QtGui.QStyledItemDelegate.paint(self, painter, option, index)
-
-        text = ustr(index.data().toPyObject())
+            return QtWidgets.QStyledItemDelegate.paint(self, painter,
+                                                       option, index)
+        text = index.data()
         if self.case_sensitive:
             html = text.replace(self.highlight_text,
                                 '<strong>%s</strong>' % self.highlight_text)
@@ -303,25 +304,26 @@ class HighlightDelegate(QtGui.QStyledItemDelegate):
         self.doc.setHtml(html)
 
         # Painting item without text, Text Document will paint the text
-        optionV4 = QtGui.QStyleOptionViewItemV4(option)
-        self.initStyleOption(optionV4, index)
-        optionV4.text = QtCore.QString()
+        params = QtWidgets.QStyleOptionViewItem(option)
+        self.initStyleOption(params, index)
+        params.text = ''
 
-        style = QtGui.QApplication.style()
-        style.drawControl(QtGui.QStyle.CE_ItemViewItem, optionV4, painter)
+        style = QtWidgets.QApplication.style()
+        style.drawControl(QtWidgets.QStyle.CE_ItemViewItem, params, painter)
         ctx = QtGui.QAbstractTextDocumentLayout.PaintContext()
 
         # Highlighting text if item is selected
-        if (optionV4.state & QtGui.QStyle.State_Selected):
-            color = optionV4.palette.color(QtGui.QPalette.Active,
-                                           QtGui.QPalette.HighlightedText)
+        if (params.state & QtWidgets.QStyle.State_Selected):
+            color = params.palette.color(QtGui.QPalette.Active,
+                                         QtGui.QPalette.HighlightedText)
             ctx.palette.setColor(QtGui.QPalette.Text, color)
 
         # translate the painter to where the text is drawn
-        rect = style.subElementRect(QtGui.QStyle.SE_ItemViewItemText, optionV4)
+        item_text = QtWidgets.QStyle.SE_ItemViewItemText
+        rect = style.subElementRect(item_text, params)
         painter.save()
 
-        start = rect.topLeft() + QtCore.QPoint(3, 0)
+        start = rect.topLeft() + QtCore.QPoint(defs.margin, 0)
         painter.translate(start)
 
         # tell the text document to draw the html for us
@@ -338,6 +340,10 @@ def ref_sort_key(ref):
 
 class CompletionModel(QtGui.QStandardItemModel):
 
+    updated = Signal()
+    items_gathered = Signal(object)
+    model_updated = Signal()
+
     def __init__(self, parent):
         QtGui.QStandardItemModel.__init__(self, parent)
         self.match_text = ''
@@ -345,9 +351,8 @@ class CompletionModel(QtGui.QStandardItemModel):
         self.case_sensitive = False
 
         self.update_thread = GatherCompletionsThread(self)
-        self.connect(self.update_thread,
-                     SIGNAL('items_gathered(PyQt_PyObject)'),
-                     self.apply_matches, Qt.QueuedConnection)
+        self.update_thread.items_gathered.connect(self.apply_matches,
+                                                  type=Qt.QueuedConnection)
 
     def update(self):
         case_sensitive = self.update_thread.case_sensitive
@@ -393,7 +398,15 @@ class CompletionModel(QtGui.QStandardItemModel):
 
         self.clear()
         self.invisibleRootItem().appendRows(items)
-        self.emit(SIGNAL('updated()'))
+        self.updated.emit()
+
+
+def _identity(x):
+    return x
+
+
+def _lower(x):
+    return x.lower()
 
 
 def filter_matches(match_text, candidates, case_sensitive,
@@ -401,9 +414,9 @@ def filter_matches(match_text, candidates, case_sensitive,
     """Filter candidates and return the matches"""
 
     if case_sensitive:
-        case_transform = lambda x: x
+        case_transform = _identity
     else:
-        case_transform = lambda x: x.lower()
+        case_transform = _lower
 
     if match_text:
         match_text = case_transform(match_text)
@@ -426,16 +439,15 @@ def filter_path_matches(match_text, file_list, case_sensitive):
     return (paths, dirs)
 
 
-class Completer(QtGui.QCompleter):
+class Completer(QtWidgets.QCompleter):
 
     def __init__(self, model, parent):
-        QtGui.QCompleter.__init__(self, parent)
+        QtWidgets.QCompleter.__init__(self, parent)
         self._model = model
-        self.setCompletionMode(QtGui.QCompleter.UnfilteredPopupCompletion)
+        self.setCompletionMode(QtWidgets.QCompleter.UnfilteredPopupCompletion)
         self.setCaseSensitivity(Qt.CaseInsensitive)
 
-        self.connect(model, SIGNAL(UPDATE_SIGNAL),
-                     self.update, Qt.QueuedConnection)
+        model.model_updated.connect(self.update, type=Qt.QueuedConnection)
         self.setModel(model)
 
     def update(self):
@@ -454,24 +466,24 @@ class GitCompletionModel(CompletionModel):
         CompletionModel.__init__(self, parent)
         self.main_model = model = main.model()
         msg = model.message_updated
-        model.add_observer(msg, self.emit_update)
+        model.add_observer(msg, self.emit_model_updated)
 
     def gather_matches(self, case_sensitive):
         refs = filter_matches(self.match_text, self.matches(), case_sensitive,
                               sort_key=ref_sort_key)
         return (refs, (), set())
 
-    def emit_update(self):
+    def emit_model_updated(self):
         try:
-            self.emit(SIGNAL(UPDATE_SIGNAL))
-        except RuntimeError: # C++ object has been deleted
+            self.model_updated.emit()
+        except RuntimeError:  # C++ object has been deleted
             self.dispose()
 
     def matches(self):
         return []
 
     def dispose(self):
-        self.main_model.remove_observer(self.emit_update)
+        self.main_model.remove_observer(self.emit_model_updated)
 
 
 class GitRefCompletionModel(GitCompletionModel):
@@ -571,10 +583,8 @@ class GitTrackedCompletionModel(GitPathCompletionModel):
 
     def __init__(self, parent):
         GitPathCompletionModel.__init__(self, parent)
-        self.connect(self, SIGNAL(UPDATE_SIGNAL),
-                     self.gather_paths, Qt.QueuedConnection)
+        self.model_updated.connect(self.gather_paths, type=Qt.QueuedConnection)
         self._paths = []
-        self._updated = False
 
     def gather_paths(self):
         self._paths = gitcmds.tracked_files()
@@ -594,10 +604,8 @@ class GitLogCompletionModel(GitRefCompletionModel):
 
     def __init__(self, parent):
         GitRefCompletionModel.__init__(self, parent)
-        self.connect(self, SIGNAL(UPDATE_SIGNAL),
-                     self.gather_paths, Qt.QueuedConnection)
+        self.model_updated.connect(self.gather_paths, type=Qt.QueuedConnection)
         self._paths = []
-        self._updated = False
 
     def gather_paths(self):
         self._paths = gitcmds.tracked_files()
@@ -642,14 +650,14 @@ GitStatusFilterLineEdit = bind_lineedit(GitStatusFilterCompletionModel)
 GitTrackedLineEdit = bind_lineedit(GitTrackedCompletionModel)
 
 
-class GitDialog(QtGui.QDialog):
+class GitDialog(QtWidgets.QDialog):
 
     def __init__(self, lineedit, title, button_text, parent, icon=None):
-        QtGui.QDialog.__init__(self, parent)
+        QtWidgets.QDialog.__init__(self, parent)
         self.setWindowTitle(title)
         self.setMinimumWidth(333)
 
-        self.label = QtGui.QLabel()
+        self.label = QtWidgets.QLabel()
         self.label.setText(title)
 
         self.lineedit = lineedit()
@@ -669,18 +677,17 @@ class GitDialog(QtGui.QDialog):
                                         self.button_layout)
         self.setLayout(self.main_layout)
 
+        self.lineedit.textChanged.connect(self.text_changed)
+        self.lineedit.enter.connect(self.accept)
+
         qtutils.connect_button(self.ok_button, self.accept)
         qtutils.connect_button(self.close_button, self.reject)
 
-        self.connect(self.lineedit, SIGNAL('textChanged(QString)'),
-                     self.text_changed)
-        self.connect(self.lineedit, SIGNAL('return()'), self.accept)
-
         self.setWindowModality(Qt.WindowModal)
         self.ok_button.setEnabled(False)
 
     def text(self):
-        return ustr(self.lineedit.text())
+        return self.lineedit.text()
 
     def text_changed(self, txt):
         self.ok_button.setEnabled(bool(self.text()))
