@@ -1,27 +1,26 @@
 from __future__ import division, absolute_import, unicode_literals
-
 import itertools
 
-from PyQt4 import QtCore
-from PyQt4 import QtGui
-from PyQt4.QtCore import Qt
-from PyQt4.QtCore import SIGNAL
+from qtpy import QtCore
+from qtpy import QtWidgets
+from qtpy.QtCore import Qt
+from qtpy.QtCore import Signal
 
-from cola import cmds
-from cola import core
-from cola import hotkeys
-from cola import icons
-from cola import qtutils
-from cola import utils
-from cola.i18n import N_
-from cola.models import main
-from cola.models import prefs
-from cola.models import selection
-from cola.widgets import completion
-from cola.widgets import defs
+from .. import cmds
+from .. import core
+from .. import hotkeys
+from .. import icons
+from .. import qtutils
+from .. import utils
+from ..i18n import N_
+from ..models import main
+from ..models import prefs
+from ..models import selection
+from . import completion
+from . import defs
 
 
-class StatusWidget(QtGui.QWidget):
+class StatusWidget(QtWidgets.QWidget):
     """
     Provides a git-status-like repository widget.
 
@@ -29,8 +28,9 @@ class StatusWidget(QtGui.QWidget):
     Qt signals.
 
     """
+
     def __init__(self, titlebar, parent=None):
-        QtGui.QWidget.__init__(self, parent)
+        QtWidgets.QWidget.__init__(self, parent)
 
         tooltip = N_('Toggle the paths filter')
         icon = icons.ellipsis()
@@ -82,7 +82,11 @@ class StatusWidget(QtGui.QWidget):
         self.tree.move_down()
 
 
-class StatusTreeWidget(QtGui.QTreeWidget):
+class StatusTreeWidget(QtWidgets.QTreeWidget):
+    # Signals
+    about_to_update = Signal()
+    updated = Signal()
+
     # Item categories
     idx_header = -1
     idx_staged = 0
@@ -95,9 +99,9 @@ class StatusTreeWidget(QtGui.QTreeWidget):
     mode = property(lambda self: self.m.mode)
 
     def __init__(self, parent=None):
-        QtGui.QTreeWidget.__init__(self, parent)
+        QtWidgets.QTreeWidget.__init__(self, parent)
 
-        self.setSelectionMode(QtGui.QAbstractItemView.ExtendedSelection)
+        self.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
         self.headerItem().setHidden(True)
         self.setAllColumnsShowFocus(True)
         self.setSortingEnabled(False)
@@ -196,27 +200,19 @@ class StatusTreeWidget(QtGui.QTreeWidget):
             self._delete_untracked_files, delete_shortcut)
         self.delete_untracked_files_action.setIcon(icons.discard())
 
-        self.connect(self, SIGNAL('about_to_update()'),
-                     self._about_to_update, Qt.QueuedConnection)
-        self.connect(self, SIGNAL('updated()'),
-                     self._updated, Qt.QueuedConnection)
+        about_to_update = self._about_to_update
+        self.about_to_update.connect(about_to_update, type=Qt.QueuedConnection)
+        self.updated.connect(self.refresh, type=Qt.QueuedConnection)
 
         self.m = main.model()
         self.m.add_observer(self.m.message_about_to_update,
-                            self.about_to_update)
-        self.m.add_observer(self.m.message_updated, self.updated)
+                            self.about_to_update.emit)
+        self.m.add_observer(self.m.message_updated, self.updated.emit)
 
-        self.connect(self, SIGNAL('itemSelectionChanged()'),
-                     self.show_selection)
-
-        self.connect(self, SIGNAL('itemDoubleClicked(QTreeWidgetItem*,int)'),
-                     self.double_clicked)
-
-        self.connect(self, SIGNAL('itemCollapsed(QTreeWidgetItem*)'),
-                     lambda x: self.update_column_widths())
-
-        self.connect(self, SIGNAL('itemExpanded(QTreeWidgetItem*)'),
-                     lambda x: self.update_column_widths())
+        self.itemSelectionChanged.connect(self.show_selection)
+        self.itemDoubleClicked.connect(self.double_clicked)
+        self.itemCollapsed.connect(lambda x: self.update_column_widths())
+        self.itemExpanded.connect(lambda x: self.update_column_widths())
 
     def add_toplevel_item(self, txt, icon, hide=False):
         font = self.font()
@@ -225,14 +221,14 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         else:
             font.setItalic(True)
 
-        item = QtGui.QTreeWidgetItem(self)
+        item = QtWidgets.QTreeWidgetItem(self)
         item.setFont(0, font)
         item.setText(0, txt)
         item.setIcon(0, icon)
         if prefs.bold_headers():
             item.setBackground(0, self.palette().midlight())
         if hide:
-            self.setItemHidden(item, True)
+            item.setHidden(True)
 
     def restore_selection(self):
         if not self.old_selection or not self.old_contents:
@@ -244,10 +240,10 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         def mkselect(lst, widget_getter):
             def select(item, current=False):
                 idx = lst.index(item)
-                widget = widget_getter(idx)
+                item = widget_getter(idx)
                 if current:
-                    self.setCurrentItem(widget)
-                self.setItemSelected(widget, True)
+                    self.setCurrentItem(item)
+                item.setSelected(True)
             return select
 
         select_staged = mkselect(new_c.staged, self.staged_item)
@@ -256,17 +252,17 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         select_untracked = mkselect(new_c.untracked, self.untracked_item)
 
         saved_selection = [
-        (set(new_c.staged), old_c.staged, set(old_s.staged),
-            select_staged),
+            (set(new_c.staged), old_c.staged, set(old_s.staged),
+             select_staged),
 
-        (set(new_c.unmerged), old_c.unmerged, set(old_s.unmerged),
-            select_unmerged),
+            (set(new_c.unmerged), old_c.unmerged, set(old_s.unmerged),
+             select_unmerged),
 
-        (set(new_c.modified), old_c.modified, set(old_s.modified),
-            select_modified),
+            (set(new_c.modified), old_c.modified, set(old_s.modified),
+             select_modified),
 
-        (set(new_c.untracked), old_c.untracked, set(old_s.untracked),
-            select_untracked),
+            (set(new_c.untracked), old_c.untracked, set(old_s.untracked),
+             select_untracked),
         ]
 
         # Restore the current item
@@ -276,7 +272,7 @@ class StatusTreeWidget(QtGui.QTreeWidget):
                 item = self.invisibleRootItem().child(idx)
                 if item is not None:
                     self.setCurrentItem(item)
-                    self.setItemSelected(item, True)
+                    item.setSelected(True)
                 return
             # Reselect the current item
             selection_info = saved_selection[category]
@@ -367,9 +363,6 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         parent = self.topLevelItem(idx)
         return parent.child(itemidx)
 
-    def about_to_update(self):
-        self.emit(SIGNAL('about_to_update()'))
-
     def _about_to_update(self):
         self.save_scrollbars()
         self.save_selection()
@@ -403,11 +396,7 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         self.old_selection = self.selection()
         self.old_current_item = self.current_item()
 
-    def updated(self):
-        """Update display from model data."""
-        self.emit(SIGNAL('updated()'))
-
-    def _updated(self):
+    def refresh(self):
         self.set_staged(self.m.staged)
         self.set_modified(self.m.modified)
         self.set_unmerged(self.m.unmerged)
@@ -448,10 +437,8 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         """Add a list of items to a treewidget item."""
         self.blockSignals(True)
         parent = self.topLevelItem(idx)
-        if items:
-            self.setItemHidden(parent, False)
-        else:
-            self.setItemHidden(parent, True)
+        hide = not bool(items)
+        parent.setHidden(hide)
 
         # sip v4.14.7 and below leak memory in parent.takeChildren()
         # so we use this backwards-compatible construct instead
@@ -544,7 +531,7 @@ class StatusTreeWidget(QtGui.QTreeWidget):
             action.setShortcut(hotkeys.STAGE_SELECTION)
 
         # Do all of the selected items exist?
-        all_exist = all(not i in self.m.staged_deleted and core.exists(i)
+        all_exist = all(i not in self.m.staged_deleted and core.exists(i)
                         for i in self.staged())
 
         if all_exist:
@@ -632,7 +619,7 @@ class StatusTreeWidget(QtGui.QTreeWidget):
             action.setShortcut(hotkeys.STAGE_SELECTION)
 
         # Do all of the selected items exist?
-        all_exist = all(not i in self.m.unstaged_deleted and core.exists(i)
+        all_exist = all(i not in self.m.unstaged_deleted and core.exists(i)
                         for i in self.staged())
 
         if all_exist and self.unstaged():
@@ -694,7 +681,6 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         menu.addAction(self.view_history_action)
         return menu
 
-
     def _delete_untracked_files(self):
         cmds.do(cmds.Delete, self.untracked())
 
@@ -791,7 +777,7 @@ class StatusTreeWidget(QtGui.QTreeWidget):
             hscrollbar.setValue(hscroll)
 
         self.setCurrentItem(item)
-        self.setItemSelected(item, True)
+        item.setSelected(True)
 
     def staged(self):
         return self._subtree_selection(self.idx_staged, self.m.staged)
@@ -863,7 +849,7 @@ class StatusTreeWidget(QtGui.QTreeWidget):
                 self.idx_staged: cmds.DiffStagedSummary,
                 self.idx_modified: cmds.Diffstat,
                 # TODO implement UnmergedSummary
-                #self.idx_unmerged: cmds.UnmergedSummary,
+                # self.idx_unmerged: cmds.UnmergedSummary,
                 self.idx_untracked: cmds.UntrackedSummary,
             }.get(idx, cmds.Diffstat)
             cmds.do(cls)
@@ -934,10 +920,12 @@ class StatusTreeWidget(QtGui.QTreeWidget):
         """Copy a selected relative path to the clipboard"""
         self.copy_path(absolute=False)
 
+    def _item_filter(self, item):
+        return not item.deleted and core.exists(item.path)
+
     def mimeData(self, items):
         """Return a list of absolute-path URLs"""
-        item_filter = lambda item: not item.deleted and core.exists(item.path)
-        paths = qtutils.paths_from_items(items, item_filter=item_filter)
+        paths = qtutils.paths_from_items(items, item_filter=self._item_filter)
         return qtutils.mimedata_from_paths(paths)
 
     def mimeTypes(self):
@@ -949,13 +937,14 @@ class StatusTreeWidget(QtGui.QTreeWidget):
 
     def view_history(self):
         """Signal that we should view history for paths."""
-        cmds.do(cmds.VisualizePaths, selection.union(selection.selection_model()))
+        cmds.do(cmds.VisualizePaths,
+                selection.union(selection.selection_model()))
 
 
-class StatusFilterWidget(QtGui.QWidget):
+class StatusFilterWidget(QtWidgets.QWidget):
 
     def __init__(self, parent=None):
-        QtGui.QWidget.__init__(self, parent)
+        QtWidgets.QWidget.__init__(self, parent)
         self.main_model = main.model()
 
         hint = N_('Filter paths...')
@@ -968,10 +957,11 @@ class StatusFilterWidget(QtGui.QWidget):
         self.main_layout = qtutils.hbox(defs.no_margin, defs.spacing, self.text)
         self.setLayout(self.main_layout)
 
-        self.connect(self.text, SIGNAL('changed()'), self.apply_filter)
-        self.connect(self.text, SIGNAL('cleared()'), self.apply_filter)
-        self.connect(self.text, SIGNAL('return()'), self.apply_filter)
-        self.connect(self.text, SIGNAL('editingFinished()'), self.apply_filter)
+        text = self.text
+        text.changed.connect(self.apply_filter)
+        text.cleared.connect(self.apply_filter)
+        text.enter.connect(self.apply_filter)
+        text.editingFinished.connect(self.apply_filter)
 
     def apply_filter(self):
         text = self.text.value()
